@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Base routines
 #
-# $Id: LONCAPA.pm,v 1.22 2006/12/20 22:23:50 albertel Exp $
+# $Id: LONCAPA.pm,v 1.23 2007/01/10 20:22:30 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -43,6 +43,7 @@ use vars qw($match_domain   $match_not_domain
 	    $match_username $match_not_username
 	    $match_courseid $match_not_courseid
 	    $match_name
+            $match_lonid
 	    $match_handle   $match_not_handle);
 
 require Exporter;
@@ -54,11 +55,13 @@ our @EXPORT_OK = qw($match_domain   $match_not_domain
 		    $match_username $match_not_username
 		    $match_courseid $match_not_courseid
 		    $match_name
+		    $match_lonid
 		    $match_handle   $match_not_handle);
 our %EXPORT_TAGS = ( 'match' =>[qw($match_domain   $match_not_domain
 				   $match_username $match_not_username
 				   $match_courseid $match_not_courseid
 				   $match_name
+				   $match_lonid
 				   $match_handle   $match_not_handle)],);
 my %perlvar;
 
@@ -136,6 +139,8 @@ sub clean_name {
     return $name;
 }
 
+$match_lonid     = $LONCAPA::lonid_re     = qr{[\w\-.]+};
+
 sub split_courseid {
     my ($courseid) = @_;
     my  ($domain,$coursenum) = 
