@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Switch Servers Handler
 #
-# $Id: switchserver.pm,v 1.10 2006/11/23 01:49:41 albertel Exp $
+# $Id: switchserver.pm,v 1.11 2007/01/12 15:44:27 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -105,6 +105,9 @@ sub handler {
     if ($env{'request.sso.login'}) {
 	$info{'sso.login'} = $env{'request.sso.login'};
     }
+    if ($env{'request.sso.reloginserver'}) {
+        $info{'sso.reloginserver'} = $env{'request.sso.reloginserver'};
+    }
     my $token = &Apache::lonnet::tmpput(\%info,$env{'form.otherserver'});
     my $switch='<meta HTTP-EQUIV="Refresh" CONTENT="0.5; url=http://'.$switch_to.'/adm/login?domain='.$env{'user.domain'}.'&username='.$env{'user.name'}.'&token='.$token.'">';
     my $start_page = &Apache::loncommon::start_page('Switching Server ...',
