@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA 
 # definition of tags that give a structure to a document
 #
-# $Id: bridgetask.pm,v 1.221 2007/01/19 23:43:50 albertel Exp $
+# $Id: bridgetask.pm,v 1.224 2007/01/26 19:06:37 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -868,8 +868,8 @@ sub get_key_todo {
 	my ($symb,$cid)=&Apache::lonnet::whichuser();
 	my $cnum  = $env{'course.'.$cid.'.num'};
 	my $cdom  = $env{'course.'.$cid.'.domain'};
-	my $uname = $env{'form.gradinguser'};
-	my $udom  = $env{'form.gradingdomain'};
+	my $uname = &LONCAPA::clean_username($env{'form.gradinguser'});
+	my $udom  = &LONCAPA::clean_domain($env{'form.gradingdomain'});
 
 	my $gradingkey=&encode_queue_key($symb,$udom,$uname);
 
@@ -2289,10 +2289,10 @@ sub end_Dimension {
 		    ('sub' x $dimension{$dim}{'depth'}).'question';
 		$ucquestion =~ s/^(.)/uc($1)/e;
 		if ($dim_status eq 'pass') {
-		    $dim_info.='<h3>'.$ucquestion.' : you passed the above '.$mandatory.' '.$question.'</h3>';
+		    $dim_info.='<h3>'.$ucquestion.' : you passed this '.$mandatory.' '.$question.'</h3>';
 		}
 		if ($dim_status eq 'fail') {
-		    $dim_info.='<h3>'.$ucquestion.' : you did not pass the above '.$mandatory.' '.$question.'</h3>';
+		    $dim_info.='<h3>'.$ucquestion.' : you did not pass this '.$mandatory.' '.$question.'</h3>';
 		}
 		my %counts = &get_counts($dim,$instance,$parstack,
 					 $safeeval);
