@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA 
 # implements the tags that control the hints
 #
-# $Id: hint.pm,v 1.62 2006/03/07 22:42:47 albertel Exp $
+# $Id: hint.pm,v 1.62.2.1 2006/12/19 00:52:44 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -29,9 +29,13 @@
 package Apache::hinttags; 
 
 use strict;
-use Apache::lonnet;
+use Apache::lonnet();
 use capa;
+use Apache::caparesponse();
+use Apache::response();
 use Apache::lonlocal;
+use Storable qw(dclone);
+
 
 BEGIN {
     &Apache::lonxml::register('Apache::hinttags',('hintgroup','hintpart','numericalhint','stringhint','formulahint','optionhint','radiobuttonhint'));
@@ -106,6 +110,7 @@ sub start_numericalhint {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
     #do everything in end, so intervening <responseparams> work
     &Apache::response::start_hintresponse($parstack,$safeeval);
+    &Apache::caparesponse::push_answer();
     my $result;
     if ($target eq 'edit') {
 	$result.=&Apache::edit::tag_start($target,$token);
@@ -116,12 +121,10 @@ sub start_numericalhint {
 		&Apache::loncommon::help_open_topic('Physical_Units');
 	    $result.=&Apache::edit::text_arg('Format:','format',$token,4).
 		&Apache::loncommon::help_open_topic('Numerical_Response_Format');
-	} elsif ($token->[1] eq 'stringhint') {
-	    $result.=&Apache::edit::select_arg('Type:','type',
-			    [['cs','Case Sensitive'],['ci','Case Insensitive'],
-			     ['mc','Case Insensitive, Any Order']],$token);
 	} elsif ($token->[1] eq 'formulahint') {
-	    $result.=&Apache::edit::text_arg('Sample Points:','samples',$token,40);
+	    $result.=&Apache::edit::text_arg('Sample Points:','samples',
+					     $token,40).
+	        &Apache::loncommon::help_open_topic('Formula_Response_Sampling');
 	}
 	$result.=&Apache::edit::end_row();
 	$result.=&Apache::edit::start_spanning_row();
@@ -131,10 +134,6 @@ sub start_numericalhint {
 	    $constructtag=&Apache::edit::get_new_args($token,$parstack,
 						     $safeeval,'name',
 						     'answer','unit','format');
-	} elsif ($token->[1] eq 'stringhint') {
-	    $constructtag=&Apache::edit::get_new_args($token,$parstack,
-						     $safeeval,'name','answer',
-						     'type');
 	} elsif ($token->[1] eq 'formulahint') {
 	    $constructtag=&Apache::edit::get_new_args($token,$parstack,
 						     $safeeval,'name','answer',
@@ -158,51 +157,66 @@ sub end_numericalhint {
 	    &Apache::lonxml::default_homework_load($safeeval);
 	}
 	$safeeval->share_from('capa',['&caparesponse_capa_check_answer']);
-	my $name= &Apache::lonxml::get_param('name',$parstack,$safeeval);
+	my $hint_name= &Apache::lonxml::get_param('name',$parstack,$safeeval);
 	&Apache::response::setup_params('numericalhint',$safeeval);
+
 	my $partid=$Apache::inputtags::part;
 	my $id=$Apache::inputtags::hint[-1];
 	#id submissions occured under
 	my $submitid=$Apache::inputtags::response[-1];
+
 	my $response = $Apache::lonhomework::history{
 			    "resource.$partid.$submitid.submission"};
 	&Apache::lonxml::debug("hintgroup is using $response<br />\n");
+
+	my @args = ('type','tol','sig','ans_fmt','unit','calc','samples');
+	my $args_ref =
+	    &Apache::caparesponse::setup_capa_args($safeeval,$parstack,
+						   \@args,$response);
+
 	my $hideunit=&Apache::response::get_response_param($partid.'_'.$submitid,'turnoffunit');
-	my $args_ref= \%{$safeeval->varglob('LONCAPA::CAPAresponse_args')};
-	$$args_ref{'response'}=$response;
-	#need to get all possible parms
-	foreach my $arg ('type','tol','sig','ans_fmt','unit','calc',
-			 'samples') {
-	    $$args_ref{$arg}=
-		&Apache::lonxml::get_param($arg,$parstack,$safeeval);
-	}
-	foreach my $key (keys(%Apache::inputtags::params)) {
-	    $$args_ref{$key}=$Apache::inputtags::params{$key};
-	}
 	if (lc($hideunit) eq "yes") { delete($$args_ref{'unit'}); }
+
 	if ($$tagstack[-1] eq 'formulahint') {
 	    $$args_ref{'type'}='fml';
 	} elsif ($$tagstack[-1] eq 'numericalhint') {
 	    $$args_ref{'type'}='float';
 	}
-	my @answer=&Apache::lonxml::get_param_var('answer',$parstack,$safeeval);
-	&Apache::lonxml::debug('answer is'.join(':',@answer));
-	@{$safeeval->varglob('LONCAPA::CAPAresponse_answer')}=@answer;
-		
-	($result,my @msgs) = &Apache::run::run("&caparesponse_check_list()",
-						$safeeval);
-	&Apache::lonxml::debug('msgs are'.join(':',@msgs));
-	&Apache::lonxml::debug("result:$result:$Apache::lonxml::curdepth");
-	my ($awards)=split(/:/,$result);
-	my (@awards) = split(/,/,$awards);
-	my ($ad, $msg) = &Apache::inputtags::finalizeawards(\@awards,\@msgs);
-	if ($ad eq 'EXACT_ANS' || $ad eq 'APPROX_ANS') { push (@Apache::hint::which,$name); }
+	&Apache::caparesponse::add_in_tag_answer($parstack,$safeeval);
+	my %answer = &Apache::caparesponse::get_answer();
+	my (@final_awards,@final_msgs,@ans_names);
+	foreach my $ans_name (keys(%answer)) {
+	    &Apache::lonxml::debug(" doing $ans_name with ".join(':',@{ $answer{$ans_name}{'answers'} }));
+	
+	    ${$safeeval->varglob('LONCAPA::CAPAresponse_answer')}=
+		dclone($answer{$ans_name});
+	    &Apache::caparesponse::setup_capa_response($args_ref,$response);
+	    my ($result,@msgs) = 
+		&Apache::run::run("&caparesponse_check_list()",$safeeval);
+	    &Apache::lonxml::debug("checking $ans_name $result with $response");
+	    &Apache::lonxml::debug('msgs are '.join(':',@msgs));
+	    my ($awards)=split(/:/,$result);
+	    my @awards= split(/,/,$awards);
+	    my ($ad, $msg) = 
+		&Apache::inputtags::finalizeawards(\@awards,\@msgs);
+	    push(@final_awards,$ad);
+	    push(@final_msgs,$msg);
+	    push(@ans_names,$ans_name);
+	}
+	my ($ad, $msg, $ans_name) =
+	    &Apache::inputtags::finalizeawards(\@final_awards,
+					       \@final_msgs,
+					       \@ans_names,1);
+	if ($ad eq 'EXACT_ANS' || $ad eq 'APPROX_ANS') {
+	    push(@Apache::hint::which,$hint_name);	
+	}
 	$result='';
     } elsif ($target eq 'meta') {
 	$result=&Apache::response::meta_package_write($token->[1]);
     } elsif ($target eq 'edit') {
 	$result.=&Apache::edit::end_row().&Apache::edit::end_table();
     }
+    &Apache::caparesponse::pop_answer();
     &Apache::response::end_hintresponse();
     return $result;
 }
@@ -250,9 +264,8 @@ sub end_stringhint {
 	if (!$Apache::lonxml::default_homework_loaded) {
 	    &Apache::lonxml::default_homework_load($safeeval);
 	}
-	my $answer=&Apache::lonxml::get_param('answer',$parstack,$safeeval);
 	$safeeval->share_from('capa',['&caparesponse_capa_check_answer']);
-	my $name= &Apache::lonxml::get_param('name',$parstack,$safeeval);
+	my $hint_name= &Apache::lonxml::get_param('name',$parstack,$safeeval);
 	&Apache::response::setup_params('stringhint',$safeeval);
 	my $partid=$Apache::inputtags::part;
 	my $id=$Apache::inputtags::hint[-1];
@@ -261,11 +274,11 @@ sub end_stringhint {
 	my $response = $Apache::lonhomework::history{
 			    "resource.$partid.$submitid.submission"};
 	&Apache::lonxml::debug("hintgroup is using $response<br />\n");
-	my $args_ref= \%{$safeeval->varglob('LONCAPA::CAPAresponse_args')};
-	$$args_ref{'response'}=$response;
-	my $type=$$args_ref{'type'}=&Apache::lonxml::get_param('type',$parstack,$safeeval);
+	my $type = &Apache::lonxml::get_param('type',$parstack,$safeeval);
 	my ($ad,$msg);
 	if ($type eq 're' ) {
+	    my $answer=&Apache::lonxml::get_param('answer',$parstack,
+						  $safeeval);
 	    ${$safeeval->varglob('LONCAPA::response')}=$response;
 	    my $compare='=';
 	    if ($answer=~/^\s*NOT\s*/) {
@@ -279,22 +292,34 @@ sub end_stringhint {
 	    &Apache::lonxml::debug("current $answer");
 	    $ad = ($result) ? 'APPROX_ANS' : 'INCORRECT';
 	} else { 
-	    foreach my $key (keys(%Apache::inputtags::params)) {
-		$$args_ref{$key}=$Apache::inputtags::params{$key};
+	    my @args = ('type');
+	    my $args_ref = 
+		&Apache::caparesponse::setup_capa_args($safeeval,$parstack,
+						       \@args,$response);
+	    &Apache::caparesponse::add_in_tag_answer($parstack,$safeeval);
+	    my (@final_awards,@final_msgs,@ans_names);
+	    my %answer = &Apache::caparesponse::get_answer();
+	    foreach my $ans_name (keys(%answer)) {
+		&Apache::lonxml::debug(" doing $ans_name with ".join(':',@{ $answer{$ans_name}{'answers'} }));
+		${$safeeval->varglob('LONCAPA::CAPAresponse_answer')}=dclone($answer{$ans_name});
+		my ($result, @msgs)=&Apache::run::run("&caparesponse_check_list()",$safeeval);
+		&Apache::lonxml::debug('msgs are'.join(':',@msgs));
+		my ($awards) = split(/:/,$result);
+		my (@awards) = split(/,/,$awards);
+		($ad,$msg) = 
+		    &Apache::inputtags::finalizeawards(\@awards,\@msgs);
+		push(@final_awards,$ad);
+		push(@final_msgs,$msg);
+		push(@ans_names,$ans_name);
+		&Apache::lonxml::debug("\n<br>result:$result:$Apache::lonxml::curdepth<br>\n");
 	    }
-	    &Apache::lonxml::debug('answer is'.$answer);
-	    @{$safeeval->varglob('LONCAPA::CAPAresponse_answer')}=($answer);
-	    
-	    ($result,my @msgs)=&Apache::run::run("&caparesponse_check_list()",
-						   $safeeval);
-	    &Apache::lonxml::debug('msgs are'.join(':',@msgs));
-	    &Apache::lonxml::debug("result:$result:$Apache::lonxml::curdepth");
-	    my ($awards)=split(/:/,$result);
-	    my (@awards) = split(/,/,$awards);
-	    ($ad, $msg) = &Apache::inputtags::finalizeawards(\@awards,\@msgs);
+	    my ($ad, $msg, $ans_name) = 
+		&Apache::inputtags::finalizeawards(\@final_awards,
+						   \@final_msgs,
+						   \@ans_names,1);
 	}
 	if ($ad eq 'EXACT_ANS' || $ad eq 'APPROX_ANS') { 
-	    push (@Apache::hint::which,$name);
+	    push(@Apache::hint::which,$hint_name);
 	}
 	$result='';
     } elsif ($target eq 'meta') {
