@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Directory Indexer
 #
-# $Id: lonindexer.pm,v 1.155 2006/12/11 02:12:08 albertel Exp $
+# $Id: lonindexer.pm,v 1.156 2007/01/16 21:20:57 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -680,7 +680,7 @@ sub get_list {
 	$uri=~s/\/+/\//g;
 	foreach (&Apache::lonsequence::attemptread(&Apache::lonnet::filelocation('',$uri))) {
 	    my @ratpart=split(/\:/,$_);
-	    push @list,$ratpart[1];
+	    push(@list,&LONCAPA::map::qtescape($ratpart[1]));
 	} 
 	$hash{'dirlist_files_'.$luri} = join("\n",@list);
     } else {
@@ -689,7 +689,7 @@ sub get_list {
 	$hash{'dirlist_files_'.$luri} = join("\n",@list);
 	$hash{'dirlist_timestamp_files_'.$luri} = time;
     }
-    return @list=&match_ext($r,@list);
+    return @list=&match_ext($r,@list);    
 }
 
 sub dynmetaread {
