@@ -1,5 +1,5 @@
 #
-# $Id: lonsupportreq.pm,v 1.41 2006/12/21 18:32:54 raeburn Exp $
+# $Id: lonsupportreq.pm,v 1.42 2006/12/22 20:51:27 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -27,7 +27,6 @@
 package Apache::lonsupportreq;
 
 use strict;
-use lib qw(/home/httpd/lib/perl);
 use MIME::Types;
 use MIME::Lite;
 use CGI::Cookie();
@@ -48,6 +47,10 @@ sub handler {
     if ($r->header_only) {
         return OK;
     }
+    if ($r->uri eq '/adm/helpdesk') {
+	&Apache::lonlocal::get_language_handle($r);
+    }
+
     &Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'},['origurl','function']);
     if ($r->uri eq '/adm/helpdesk') {
         &Apache::lonacc::get_posted_cgi($r);
