@@ -1,6 +1,7 @@
 #!/usr/bin/perl
 # CGI-script to run LaTeX, dvips, ps2ps, ps2pdf etc.
 #
+# $Id: printout.pl,v 1.120 2007/01/19 20:22:33 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -603,9 +604,9 @@ foreach $texfile (@texfile) {
 	      $texps =~ s/\.tex/\.ps/;
 	      my @garb = ($texaux,$texdvi,$texps);
 #	  unlink @garb;
-	      unlink $duefile;
+	      unlink($duefile);
 	      print "<a href=\"/prtspool/$pdf_file\">Your PDF document</a>";
-	      unlink $missfonts_file;
+	      unlink($missfonts_file);
 
 	  }
 	  if ($advanced_role) {  
@@ -756,11 +757,11 @@ foreach $texfile (@texfile) {
 	      $texps =~ s/\.tex/\.ps/;
 	      my @garb = ($texlog,$texaux,$texdvi,$texps);
 #	  unlink @garb;
-	      unlink $duefile;
+	      unlink($duefile);
 	      print "<a href=\"/prtspool/$pdf_file\">$link_text - click here to download pdf</a>";
 	      print "\n";
 	  }
-	  unlink $missfonts_file;
+	  unlink($missfonts_file);
 
       }  
   } else {
@@ -865,7 +866,7 @@ sub repaginate {
 	#
 
 	if ($line =~ /^%%Page:/) {
-	    my @pageinfo = split(/ /, $line);
+	    my @pageinfo = split(/\s+/, $line);
 	    if ($page_number < $pageinfo[1]) {
 		$page_number = $pageinfo[1];
 	    } elsif ($pageinfo[2] ne 1) {
